@@ -31,15 +31,11 @@
 #ifndef __MOUSECONFIG_H__
 #define __MOUSECONFIG_H__
 
-#include <QX11Info>
-
 #include <config-workspace.h>
 
 #include <kcmodule.h>
-#include "ui_kmousedlg.h"
-
-#define RIGHT_HANDED 0
-#define LEFT_HANDED  1
+#include "ui_kcmmouse.h"
+#include "mousesettings.h"
 
 class QCheckBox;
 class QDoubleSpinBox;
@@ -47,38 +43,10 @@ class QSlider;
 class QSpinBox;
 class QTabWidget;
 
-class KMouseDlg : public QWidget, public Ui::KMouseDlg
-{
-public:
-    KMouseDlg( QWidget *parent ) : QWidget( parent ) {
-        setupUi( this );
-    }
-};
+class MouseSettings;
+class MouseBackend;
 
-class MouseSettings
-{
-public:
-    void save(KConfig *);
-    void load(KConfig *, Display *dpy = QX11Info::display());
-    void apply(bool force=false);
-
-public:
-    int num_buttons;
-    int middle_button;
-    bool handedEnabled;
-    bool m_handedNeedsApply;
-    int handed;
-    double accelRate;
-    int thresholdMove;
-    int doubleClickInterval;
-    int dragStartTime;
-    int dragStartDist;
-    bool singleClick;
-    int wheelScrollLines;
-    bool reverseScrollPolarity;
-};
-
-class MouseConfig : public KCModule
+class MouseConfig : public KCModule, public Ui::KCMMouse
 {
     Q_OBJECT
 public:
@@ -100,31 +68,15 @@ private Q_SLOTS:
 private:
     double getAccel();
     int getThreshold();
-    int getHandedness();
+    MouseHanded getHandedness();
 
     void setAccel(double);
     void setThreshold(int);
-    void setHandedness(int);
+    void setHandedness(MouseHanded);
 
-    QDoubleSpinBox *accel;
-    QSpinBox *thresh;
-    QSpinBox *doubleClickInterval;
-    QSpinBox *dragStartTime;
-    QSpinBox *dragStartDist;
-    QSpinBox *wheelScrollLines;
-
-    QTabWidget *tabwidget;
-    QWidget *advancedTab;
-    KMouseDlg* generalTab;
     MouseSettings *settings;
 
-    QCheckBox *mouseKeys;
-    QSpinBox *mk_delay;
-    QSpinBox *mk_interval;
-    QSpinBox *mk_time_to_max;
-    QSpinBox *mk_max_speed;
-    QSpinBox *mk_curve;
+    MouseBackend *backend;
 };
 
 #endif
-
